# TAC Participation

## Description

This is the skill for participating in a TAC.

This skill is part of the Fetch.ai TAC demo. It searches for a TAC on the sOEF, and if found, participates in the TAC by communicating with the controller agent.

## Behaviours

* `tac_search`: searches for a TAC 
* `transaction_processing`: processes transactions during the competition

## Handlers

* `tac`: handles `tac` messages by the controller for participating in the competition
* `oef`: handles `oef_search` messages to find and connect with a controller

## Links

* <a href="https://docs.fetch.ai/aea/tac-skills-contract/" target="_blank">TAC Demo</a>
